.. image:: https://github.com/ArtesiaWater/waterbalans/actions/workflows/ci.yml/badge.svg
     :target: https://github.com/ArtesiaWater/waterbalans/actions/workflows/ci.yml
.. image:: https://app.codacy.com/project/badge/Grade/1fe9a28fcdd04d6cad0abb19214701a5    
     :target: https://www.codacy.com/gh/ArtesiaWater/waterbalans/dashboard?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=ArtesiaWater/waterbalans&amp;utm_campaign=Badge_Grade
.. image:: https://app.codacy.com/project/badge/Coverage/1fe9a28fcdd04d6cad0abb19214701a5    
     :target: https://www.codacy.com/gh/ArtesiaWater/waterbalans/dashboard?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=ArtesiaWater/waterbalans&amp;utm_campaign=Badge_Coverage
.. image:: https://readthedocs.org/projects/waterbalans/badge/?version=latest
    :target: https://waterbalans.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status

.. raw:: html

    <img src="https://github.com/ArtesiaWater/waterbalans/blob/master/logo.png" height="150px" width="150px" align="right">

Waternet Waterbalansen Model in Python
======================================

Deze repository bevat het Waternet Waterbalansen model, zoals uitgewerkt door
Maarten Ouboter in de Excel Waterbalans module.

Auteurs:

- R.A. Collenteur, Artesia Water 2018
- D.A. Brakenhoff, Artesia Water 2018


Installatie
===========

1. Download de data van deze repository.
2. Open een windows command window (CMD) en cd naar de map waterbalans (waar ook het bestand setup.py staat).
3. type het volgende en druk op enter::

   >>> pip install .

4. de python-module "waterbalans" wordt nu automatisch geinstalleerd.

Installatie vereisten
=====================
- Python 3.7 installatie (bij voorkeur Anaconda https://www.anaconda.com/download/)

Project Groep
=============

- Maarten Wensing (Projectleider)
- Jan Willem Voort (Gebruiker)
- Laura Moria (Gebruiker)
- Maarten Ouboter (Maker Excel-balans)
- Davíd Brakenhoff (Python Programmeur)
- Ben Staring (FEWS)
- Stefan Fritz (GIS)

Niet langer betrokken maar veel belangrijk werk verricht in de eerste fase:

- Pytrik Graafstra (Conceptueel overzicht)
- Raoul Collenteur (Python Programmeur)
